Updates the local copies of meta data used by the package.
Arguments
- force
Logical. Force update even if the remote version matches local?
- utm
Logical. Update
meta_utm_squares()as well? WARNING: This is a large and time consuming download!- verbose
Logical. Show progress messages?
Examples
nc_metadata()
#> Updating species authority...
#> Updating species codes...
#> Updating species taxonomy...
#> Updating country codes...
#> Updating state/province codes...
#> Updating subnational codes...
#> Updating IBA codes...
#> Updating BCR codes...
#> Updating BMDE Field list...
#> Metadata version updated to 2026-03-31